@@ -1,3 +1,5 @@
+import sys
+
 from setuptools_scm import integration
 from setuptools_scm.utils import do
 from setuptools_scm import git
@@ -29,6 +31,19 @@ def test_parse_describe_output(given, tag, number, node, dirty):
     assert parsed == (tag, number, node, dirty)
 
 
+def test_root_relative_to(tmpdir, wd, monkeypatch):
+    monkeypatch.delenv("SETUPTOOLS_SCM_DEBUG")
+    p = wd.cwd.ensure("sub/package", dir=1)
+    p.join("setup.py").write(
+        """from setuptools import setup
+setup(use_scm_version={"root": "../..",
+                       "relative_to": __file__})
+"""
+    )
+    res = do((sys.executable, "setup.py", "--version"), p)
+    assert res == "0.1.dev0"
+
+
 @pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/298")
 def test_file_finder_no_history(wd, caplog):
     file_list = git_find_files(str(wd.cwd))
@@ -100,6 +115,16 @@ def test_git_dirty_notag(wd):
     assert today.strftime(".d%Y%m%d") in wd.version
 
 
+@pytest.mark.issue(193)
+def test_git_worktree_support(wd, tmpdir):
+    wd.commit_testfile()
+    worktree = tmpdir.join("work_tree")
+    wd("git worktree add -b work-tree %s" % worktree)
+
+    res = do([sys.executable, "-m", "setuptools_scm", "ls"], cwd=worktree)
+    assert str(worktree) in res
+
+
 @pytest.fixture
 def shallow_wd(wd, tmpdir):
     wd.commit_testfile()
@@ -203,6 +228,15 @@ def test_not_matching_tags(wd):
     assert wd.get_version(
         tag_regex=r"^apache-arrow-([\.0-9]+)$",
         git_describe_command="git describe --dirty --tags --long --exclude *js* ",
-    ).startswith(
-        "0.11.2"
-    )
+    ).startswith("0.11.2")
+
+
+@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/381")
+def test_gitdir(monkeypatch, wd):
+    """
+    """
+    wd.commit_testfile()
+    normal = wd.version
+    # git hooks set this and break subsequent setuptools_scm unless we clean
+    monkeypatch.setenv("GIT_DIR", __file__)
+    assert wd.version == normal
